import { RTVIClientOptions, RTVIMessage, Tracks, Transport, TransportState } from "@pipecat-ai/client-js";
declare class TrackStatusMessage {
    type: string;
    receiver_index: number;
    enabled: boolean;
    constructor(receiver_index: number, enabled: boolean);
}
export interface SmallWebRTCTransportConstructorOptions {
    iceServers?: RTCIceServer[];
    waitForICEGathering?: boolean;
}
declare class RenegotiateMessage {
    type: string;
}
declare class PeerLeftMessageMessage {
    type: string;
}
type OutboundSignallingMessage = TrackStatusMessage;
type InboundSignallingMessage = RenegotiateMessage | PeerLeftMessageMessage;
declare const SIGNALLING_TYPE = "signalling";
declare class SignallingMessageObject {
    type: typeof SIGNALLING_TYPE;
    message: InboundSignallingMessage | OutboundSignallingMessage;
    constructor(message: InboundSignallingMessage | OutboundSignallingMessage);
}
/**
 * SmallWebRTCTransport is a class that provides a client-side
 * interface for connecting to the SmallWebRTCTransport provided by Pipecat
 */
export class SmallWebRTCTransport extends Transport {
    static SERVICE_NAME: string;
    constructor({ iceServers, waitForICEGathering, }?: SmallWebRTCTransportConstructorOptions);
    initialize(options: RTVIClientOptions, messageHandler: (ev: RTVIMessage) => void): void;
    initDevices(): Promise<void>;
    setAudioCodec(audioCodec: string | null): void;
    setVideoCodec(videoCodec: string | null): void;
    connect(authBundle: unknown, abortController: AbortController): Promise<void>;
    sendReadyMessage(): void;
    sendMessage(message: RTVIMessage): void;
    disconnect(): Promise<void>;
    handleMessage(message: string): void;
    handleSignallingMessage(messageObj: SignallingMessageObject): Promise<void>;
    getAllMics(): Promise<MediaDeviceInfo[]>;
    getAllCams(): Promise<MediaDeviceInfo[]>;
    getAllSpeakers(): Promise<MediaDeviceInfo[]>;
    updateMic(micId: string): Promise<void>;
    updateCam(camId: string): void;
    updateSpeaker(speakerId: string): void;
    get selectedMic(): MediaDeviceInfo | Record<string, never>;
    get selectedCam(): MediaDeviceInfo | Record<string, never>;
    get selectedSpeaker(): MediaDeviceInfo | Record<string, never>;
    set iceServers(iceServers: RTCIceServer[]);
    get iceServers(): RTCIceServer[];
    enableMic(enable: boolean): void;
    enableCam(enable: boolean): void;
    get isCamEnabled(): boolean;
    get isMicEnabled(): boolean;
    get state(): TransportState;
    set state(state: TransportState);
    get expiry(): number | undefined;
    tracks(): Tracks;
    enableScreenShare(enable: boolean): void;
    get isSharingScreen(): boolean;
}

//# sourceMappingURL=index.d.ts.map
